@@ -74,12 +74,11 @@
     }
 
     function _loadNodeData(nodeId) {
-      ironic.getNode(nodeId).then(function(response) {
-        var node = response.data;
-
+      ironic.getNode(nodeId).then(function(node) {
         ctrl.baseNode = node;
 
         ctrl.node.name = node.name;
+        ctrl.node.network_interface = node.network_interface;
         for (var i = 0; i < ctrl.drivers.length; i++) {
           if (ctrl.drivers[i].name === node.driver) {
             ctrl.selectedDriver = ctrl.drivers[i];
@@ -112,28 +111,27 @@
      */
     function buildPatch(sourceNode, targetNode) {
       var patcher = new updatePatchService.UpdatePatch();
-
-      patcher.buildPatch(sourceNode.name, targetNode.name, "/name");
-      patcher.buildPatch(sourceNode.driver, targetNode.driver, "/driver");
-      patcher.buildPatch(sourceNode.properties,
-                         targetNode.properties,
-                         "/properties");
-      patcher.buildPatch(sourceNode.extra,
-                         targetNode.extra,
-                         "/extra");
-      patcher.buildPatch(sourceNode.driver_info,
-                         targetNode.driver_info,
-                         "/driver_info");
-      patcher.buildPatch(sourceNode.instance_info,
-                         targetNode.instance_info,
-                         "/instance_info");
+      var PatchItem = function PatchItem(id, path) {
+        this.id = id;
+        this.path = path;
+      };
+      angular.forEach([new PatchItem("name", "/name"),
+                       new PatchItem("network_interface", "/network_interface"),
+                       new PatchItem("driver", "/driver"),
+                       new PatchItem("properties", "/properties"),
+                       new PatchItem("extra", "/extra"),
+                       new PatchItem("driver_info", "/driver_info"),
+                       new PatchItem("instance_info", "/instance_info")],
+                      function(item) {
+                        patcher.buildPatch(sourceNode[item.id],
+                                           targetNode[item.id],
+                                           item.path);
+                      });
 
       return patcher.getPatch();
     }
 
     ctrl.submit = function() {
-      $uibModalInstance.close();
-
       angular.forEach(ctrl.driverProperties, function(property, name) {
         $log.debug(name +
                    ", required = " + property.isRequired() +
@@ -155,13 +153,13 @@
       var patch = buildPatch(ctrl.baseNode, ctrl.node);
       $log.info("patch = " + JSON.stringify(patch.patch));
       if (patch.status === updatePatchService.UpdatePatch.status.OK) {
-        ironic.updateNode(ctrl.baseNode.uuid, patch.patch).then(function() {
+        ironic.updateNode(ctrl.baseNode.uuid, patch.patch).then(function(node) {
           $rootScope.$emit(ironicEvents.EDIT_NODE_SUCCESS);
+          $uibModalInstance.close(node);
         });
       } else {
         toastService.add('error',
                          gettext('Unable to create node update patch.'));
-
       }
     };
   }
